@@ -26,14 +26,13 @@ type Request struct {
 }
 
 func (r *Request) AuthorizeRequest(
-	addr string,
 	cconfig ClientConfig,
 	sconfig ServerConfig,
 	hc *http.Client,
 ) (codeVerifier string, err error) {
 	r.Form = url.Values{
 		"client_id":    {cconfig.ClientID},
-		"redirect_uri": {"http://" + addr + "/callback"},
+		"redirect_uri": {cconfig.RedirectURL},
 		"state":        {shortuuid.New()},
 		"nonce":        {shortuuid.New()},
 	}
@@ -50,6 +49,18 @@ func (r *Request) AuthorizeRequest(
 		r.Form.Set("scope", strings.Join(cconfig.Scopes, " "))
 	}
 
+	if cconfig.IDTokenHint != "" {
+		r.Form.Set("id_token_hint", cconfig.IDTokenHint)
+	}
+
+	if cconfig.LoginHint != "" {
+		r.Form.Set("login_hint", cconfig.LoginHint)
+	}
+
+	if cconfig.IDPHint != "" {
+		r.Form.Set("idp_hint", cconfig.IDPHint)
+	}
+
 	if cconfig.PKCE {
 		codeVerifier = RandomString(CodeVerifierLength)
 
